summaryrefslogtreecommitdiff
path: root/synproto.h
diff options
context:
space:
mode:
authorPeter Osterlund <petero2@telia.com>2004-04-22 23:32:25 +0200
committerPeter Osterlund <petero2@telia.com>2006-04-09 04:02:14 +0200
commita4ba6e264a52d475ccecf381e9b9acc63190d4f4 (patch)
treeb012ab81692c2b4b424d9b48b12162b03aa7efb2 /synproto.h
parentf1146f67f7e377d1f6f32a26bb833fc2b0ed2ed6 (diff)
Added (untested) support for ALPS touchpads using the 2.4
linux kernel.
Diffstat (limited to 'synproto.h')
-rw-r--r--synproto.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/synproto.h b/synproto.h
index 0180ed2..8562a75 100644
--- a/synproto.h
+++ b/synproto.h
@@ -67,7 +67,8 @@ struct CommData {
enum SynapticsProtocol {
SYN_PROTO_PSAUX, /* Raw psaux device */
SYN_PROTO_EVENT, /* Linux kernel event interface */
- SYN_PROTO_PSM /* FreeBSD psm driver */
+ SYN_PROTO_PSM, /* FreeBSD psm driver */
+ SYN_PROTO_ALPS /* ALPS touchpad protocol */
};
struct SynapticsHwInfo;
@@ -86,6 +87,7 @@ struct SynapticsProtocolOperations {
extern struct SynapticsProtocolOperations psaux_proto_operations;
extern struct SynapticsProtocolOperations event_proto_operations;
extern struct SynapticsProtocolOperations psm_proto_operations;
+extern struct SynapticsProtocolOperations alps_proto_operations;
#endif /* _SYNPROTO_H_ */